==> camitk_3.2.1.orig.tar.gz: camitk-3.2.1-Source/imaging/components/dicomdirectory/DicomDirectoryComponent.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#include "DicomDirectoryComponent.h"
#include "gdcmImageReader.h"
#include "vtkGDCMImageReader.h"

// Qt includes
#include <QDir>

// VTK includes
#include <vtkStringArray.h>


using namespace camitk;
using namespace gdcm;

// --------------- Constructor -------------------
DicomDirectoryComponent::DicomDirectoryComponent(const QString & path) throw(AbortException) : ImageComponent(path)
{
    // Use GDCM libraries to handle dicom volume image files
    vtkGDCMImageReader *reader = vtkGDCMImageReader::New();
    
    // Get all the files inside the directory
    QDir dir;
    dir.setCurrent(path);
    dir.setFilter(QDir::Files);
    QStringList files = dir.entryList();
    
    // indicate to the gdcm reader to read a list of files
    vtkSmartPointer<vtkStringArray> fileNames = vtkSmartPointer<vtkStringArray>::New();
    foreach(QString file, files)
        fileNames->InsertNextValue(file.toStdString().c_str());
    
    // read the bunch of files using gdcm
    reader->SetFileNames(fileNames);
    
    // read the file(s)
    reader->UpdateWholeExtent();
        
    // Get the image pixels value from the gdcm reader
    vtkSmartPointer<vtkImageData> image = reader->GetOutput();
    
    // load the image into CamiTK
    setImageData(image, false);
}

// --------------- destructor -------------------
DicomDirectoryComponent::~DicomDirectoryComponent() {

}

==> camitk_3.2.2.orig.tar.gz: camitk-3.2.2-Source/imaging/components/dicomdirectory/DicomDirectoryComponent.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#include "DicomDirectoryComponent.h"
#include "gdcmImageReader.h"
#include "vtkGDCMImageReader.h"

// Qt includes
#include <QDir>

// VTK includes
#include <vtkStringArray.h>


using namespace camitk;
using namespace gdcm;

// --------------- Constructor -------------------
DicomDirectoryComponent::DicomDirectoryComponent(const QString & path) throw(AbortException) : ImageComponent(path)
{
    // Use GDCM libraries to handle dicom volume image files
    vtkGDCMImageReader *reader = vtkGDCMImageReader::New();
    
    // Get all the files inside the directory
    QDir dir;
    dir.setCurrent(path);
    dir.setFilter(QDir::Files);
    QStringList files = dir.entryList();
    
    // indicate to the gdcm reader to read a list of files
    vtkSmartPointer<vtkStringArray> fileNames = vtkSmartPointer<vtkStringArray>::New();
    foreach(QString file, files)
        fileNames->InsertNextValue(file.toStdString().c_str());
    
    // read the bunch of files using gdcm
    reader->SetFileNames(fileNames);
    
    // read the file(s)
    reader->UpdateWholeExtent();
        
    // Get the image pixels value from the gdcm reader
    vtkSmartPointer<vtkImageData> image = reader->GetOutput();
    
    // load the image into CamiTK
    setImageData(image, false);
    
    // use gdcm reader to provide good information for the lut
    // we need to set up range and table values
    double range[2] = {0.0, 0.0};
    reader->GetOutput()->GetScalarRange(range);
    this->getLut()->SetRange(range);
    this->getLut()->SetNumberOfTableValues(abs(range[0]) + abs(range[1]));
}

// --------------- destructor -------------------
DicomDirectoryComponent::~DicomDirectoryComponent() {

}
